#include "arg.ih"

Arg     *Arg::s_arg;
string  Arg::s_dirsep("/");
char    Arg::s_optChar[] = " ";
